==> typedb_driver-3.0.0a6-py39-none-win_amd64.whl: typedb/connection/database_manager.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from __future__ import annotations

from typing import TYPE_CHECKING

from typedb.api.connection.database import DatabaseManager
from typedb.common.exception import TypeDBDriverException, ILLEGAL_STATE
from typedb.common.iterator_wrapper import IteratorWrapper
from typedb.common.native_wrapper import NativeWrapper
from typedb.connection.database import _Database
from typedb.native_driver_wrapper import databases_contains, databases_create, databases_get, \
    databases_all, database_iterator_next, TypeDBDriver as NativeDriver, TypeDBDriverExceptionNative

if TYPE_CHECKING:
    from typedb.native_driver_wrapper import TypeDBDriver as NativeDriver


class _DatabaseManager(DatabaseManager, NativeWrapper[NativeDriver]):

    def __init__(self, native_driver: NativeDriver):
        super().__init__(native_driver)

    @property
    def _native_object_not_owned_exception(self) -> TypeDBDriverException:
        return TypeDBDriverException(ILLEGAL_STATE)

    def get(self, name: str) -> _Database:
        try:
            return _Database(databases_get(self.native_object, name))
        except TypeDBDriverExceptionNative as e:
            raise TypeDBDriverException.of(e)

    def contains(self, name: str) -> bool:
        try:
            return databases_contains(self.native_object, name)
        except TypeDBDriverExceptionNative as e:
            raise TypeDBDriverException.of(e)

    def create(self, name: str) -> None:
        try:
            databases_create(self.native_object, name)
        except TypeDBDriverExceptionNative as e:
            raise TypeDBDriverException.of(e)

    def all(self) -> list[_Database]:
        try:
            return list(map(_Database, IteratorWrapper(databases_all(self.native_object), database_iterator_next)))
        except TypeDBDriverExceptionNative as e:
            raise TypeDBDriverException.of(e)

==> typedb_driver-3.2.0rc2-py39-none-win_amd64.whl: typedb/connection/database_manager.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from __future__ import annotations

from typing import TYPE_CHECKING

from typedb.api.connection.database import DatabaseManager
from typedb.common.exception import TypeDBDriverException
from typedb.common.iterator_wrapper import IteratorWrapper
from typedb.common.validation import require_non_null
from typedb.connection.database import _Database
from typedb.native_driver_wrapper import databases_contains, databases_create, databases_get, \
    databases_all, database_iterator_next, TypeDBDriverExceptionNative

if TYPE_CHECKING:
    from typedb.native_driver_wrapper import TypeDBDriver as NativeDriver


class _DatabaseManager(DatabaseManager):

    def __init__(self, native_driver: NativeDriver):
        self.native_driver = native_driver

    def get(self, name: str) -> _Database:
        require_non_null(name, "name")
        try:
            return _Database(databases_get(self.native_driver, name))
        except TypeDBDriverExceptionNative as e:
            raise TypeDBDriverException.of(e) from None

    def contains(self, name: str) -> bool:
        require_non_null(name, "name")
        try:
            return databases_contains(self.native_driver, name)
        except TypeDBDriverExceptionNative as e:
            raise TypeDBDriverException.of(e) from None

    def create(self, name: str) -> None:
        require_non_null(name, "name")
        try:
            databases_create(self.native_driver, name)
        except TypeDBDriverExceptionNative as e:
            raise TypeDBDriverException.of(e) from None

    def all(self) -> list[_Database]:
        try:
            return list(map(_Database, IteratorWrapper(databases_all(self.native_driver), database_iterator_next)))
        except TypeDBDriverExceptionNative as e:
            raise TypeDBDriverException.of(e) from None
